[−][src]Enum ffsvm::Error
Possible error types when classifying with a [SVMCore].
Variants
AttributesUnorderedThis can be emitted when creating a [SVM] from a [ModelFile]. For models generated by
libSVM's svm-train, the most common reason this occurs is skipping attributes.
All attributes must be in sequential order 0, 1, 2, ..., n. If they are not, this
error will be emitted. For more details see the documentation provided in [ModelFile].
Fields of AttributesUnordered
index: u32The index process that was not a direct successor of the previous index. Can be used for easier debugging the model file.
value: f32The value of the given index. Can be used for debugging in conjunction with index.
last_index: u32The last index processed. If everything were alright, then index should equal
last_index + 1.
NoProbabilitiesThis error can be emitted by [Predict::predict_probability()] in case the model loaded by
[ModelFile] was not trained with probability estimates (svm-train -b 1).
IterationsExceededCan be emitted by [Predict::predict_probability()] when predicting probabilities and the internal iteration limit was exceeded.
NoGammaIf the model does not have a gamma set this error may be raised.
NoCoef0If the model does not have a coef0 set this error may be raised.
NoDegreeIf the model does not have a degree set this error may be raised.
ParsingError(String)Wrapper for internal parsing error when unifiying error handling.